==> SimbioReader-0.1.4.dev1-py3-none-any.whl: SimbioReader/phases.py <==
#! /usr/bin/env python3

phases={
    "necp":{
        "start" : "2018-12-10 00:00:00",
        "stop"  : "2018-12-12 23:59:59",
        "name"  : "necp",
        "phase" : "necp",
        "LPName": "Near-Earth Commissioning Phase"
    },
    "dnecp":{
        "start": "2019-06-06 00:00:00",
        "stop" : "2019-06-06 23:59:59",
        "name" : "dnecp",
        "phase": "cruise",
        "LPName": "Cruise"
    },
    "ico1":{
        "start": "2019-06-07 00:00:00",
        "stop" : "2019-06-07 23:59:59",
        "name" : "ico1",
        "phase": "cruise",
        "LPName": "Cruise"
    },
    "ico2":{
        "start": "2019-11-27 00:00:00",
        "stop" : "2019-11-27 23:59:59",
        "name" : "ico2",
        "phase": "cruise",
        "LPName": "Cruise"
    },
    "ico3":{
        "start": "2020-06-24 00:00:00",
        "stop" : "2020-06-25 23:59:59",
        "name" : "ico3",
        "phase": "cruise",
        "LPName": "Cruise"
    },
    "ico4":{
        "start": "2020-12-14 00:00:00",
        "stop" : "2020-12-15 23:00:00",
        "name" : "ico4",
        "phase": "cruise",
        "LPName": "Cruise"
    },
    "ico4b":{
        "start": "2021-04-24 00:00:00",
        "stop" : "2021-04-25 00:00:00",
        "name" : "ico4b",
        "phase": "cruise",
        "LPName": "Cruise"
    },
    "ico5":{
        "start": "2021-06-14 00:00:00",
        "stop" : "2021-06-15 00:00:00",
        "name" : "ico5",
        "phase": "cruise",
        "LPName": "Cruise"
    },
    "ico6":{
        "start": "2021-11-21 00:00:00",
        "stop" : "2021-11-23 00:00:00",
        "name" : "ico6",
        "phase": "cruise",
        "LPName": "Cruise" 
    },
    "ico7": {
        "start": "2022-05-16 00:00:00",
        "stop": "2022-05-16 03:00:00",
        "name": "ico7",
        "phase": "cruise",
        "LPName": "Cruise"
    },
    "ico8":{
        "start": "2022-11-06 23:00:00",
        "stop": "2022-11-07 12:30:00",
        "name": "ico8",
        "phase": "cruise",
        "LPName": "Cruise"
    },
    "aswu": {
        "start": "2022-11-28 07:00:00",
        "stop": "2022-11-28 14:00:00",
        "name": "aswu",
        "phase": "cruise",
        "LPName": "Cruise"
    },
    "ico9":{
        "start": "2023-05-23 07:50:00",
        "stop": "2023-05-23 10:52:00",
        "name": "ico9",
        "phase": "cruise",
        "LPName": "Cruise"
    },
    "ssmm_load":{
        "start": "2023-05-30 11:00:00",
        "stop": "2023-06-01 18:00:00",
        "name": "ssmm_load",
        "phase": "cruise",
        "LPName": "Cruise"
    },
    "None":{
        "start" : "2021-11-23 00:00:01",
        "stop"  : "2028-12-31 23:59:59",
        "name"  : "None",
        "phase" : "None",
        "LPName": "None"
    }
}

==> SimbioReader-0.1.7.dev1-py3-none-any.whl: SimbioReader/phases.py <==
#! /usr/bin/env python3

phases={
    "necp":{
        "start" : "2018-12-10 00:00:00",
        "stop"  : "2018-12-12 23:59:59",
        "name"  : "necp",
        "phase" : "necp",
        "LPName": "Near-Earth Commissioning Phase"
    },
    "dnecp":{
        "start": "2019-06-06 00:00:00",
        "stop" : "2019-06-06 23:59:59",
        "name" : "dnecp",
        "phase": "cruise",
        "LPName": "Cruise"
    },
    "ico1":{
        "start": "2019-06-07 00:00:00",
        "stop" : "2019-06-07 23:59:59",
        "name" : "ico1",
        "phase": "cruise",
        "LPName": "Cruise"
    },
    "ico2":{
        "start": "2019-11-27 00:00:00",
        "stop" : "2019-11-27 23:59:59",
        "name" : "ico2",
        "phase": "cruise",
        "LPName": "Cruise"
    },
    "ico3":{
        "start": "2020-06-24 00:00:00",
        "stop" : "2020-06-25 23:59:59",
        "name" : "ico3",
        "phase": "cruise",
        "LPName": "Cruise"
    },
    "ico4":{
        "start": "2020-12-14 00:00:00",
        "stop" : "2020-12-15 23:00:00",
        "name" : "ico4",
        "phase": "cruise",
        "LPName": "Cruise"
    },
    "ico4b":{
        "start": "2021-04-24 00:00:00",
        "stop" : "2021-04-25 00:00:00",
        "name" : "ico4b",
        "phase": "cruise",
        "LPName": "Cruise"
    },
    "ico5":{
        "start": "2021-06-14 00:00:00",
        "stop" : "2021-06-15 00:00:00",
        "name" : "ico5",
        "phase": "cruise",
        "LPName": "Cruise"
    },
    "ico6":{
        "start": "2021-11-21 00:00:00",
        "stop" : "2021-11-23 00:00:00",
        "name" : "ico6",
        "phase": "cruise",
        "LPName": "Cruise" 
    },
    "ico7": {
        "start": "2022-05-16 00:00:00",
        "stop": "2022-05-16 03:00:00",
        "name": "ico7",
        "phase": "cruise",
        "LPName": "Cruise"
    },
    "ico8":{
        "start": "2022-11-06 23:00:00",
        "stop": "2022-11-07 12:30:00",
        "name": "ico8",
        "phase": "cruise",
        "LPName": "Cruise"
    },
    "aswu": {
        "start": "2022-11-28 07:00:00",
        "stop": "2022-11-28 14:00:00",
        "name": "aswu",
        "phase": "cruise",
        "LPName": "Cruise"
    },
    "ico9":{
        "start": "2023-05-23 07:50:00",
        "stop": "2023-05-23 10:52:00",
        "name": "ico9",
        "phase": "cruise",
        "LPName": "Cruise"
    },
    "ssmm_load":{
        "start": "2023-05-30 11:00:00",
        "stop": "2023-06-01 18:00:00",
        "name": "ssmm_load",
        "phase": "cruise",
        "LPName": "Cruise"
    },
    "ico10": {
        "start": "2023-11-05 23:30:00",
        "stop": "2023-11-06 02:00:00",
        "name": "ico10",
        "phase": "cruise",
        "LPName": "Cruise"
    },
    "ico11": {
        "start": "2024-04-08 00:00:00",
        "stop": "2024-04-08 04:00:00",
        "name": "ico11",
        "phase": "cruise",
        "LPName": "Cruise"
    },
    "None":{
        "start" : "2024-04-08 04:00:01",
        "stop"  : "2028-12-31 23:59:59",
        "name"  : "None",
        "phase" : "None",
        "LPName": "None"
    }
}
